pub struct RuleOverrides(pub HashMap<String, RuleOverride>);Expand description
Rule overrides configuration
Tuple Fields
0: HashMap<String, RuleOverride>Trait Implementations
Sourceimpl Clone for RuleOverrides
impl Clone for RuleOverrides
Sourcefn clone(&self) -> RuleOverrides
fn clone(&self) -> RuleOverrides
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuleOverrides
impl Debug for RuleOverrides
Sourceimpl Default for RuleOverrides
impl Default for RuleOverrides
Sourcefn default() -> RuleOverrides
fn default() -> RuleOverrides
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RuleOverrides
impl<'de> Deserialize<'de> for RuleOverrides
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RuleOverrides
impl JsonSchema for RuleOverrides
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RuleOverrides
impl RefUnwindSafe for RuleOverrides
impl Send for RuleOverrides
impl Sync for RuleOverrides
impl Unpin for RuleOverrides
impl UnsafeUnpin for RuleOverrides
impl UnwindSafe for RuleOverrides